@@ -3,7 +3,7 @@ package Database::Async::ORM;
 use strict;
 use warnings;
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 =head1 NAME
 
@@ -392,13 +392,19 @@ sub load_from {
                         # For convenience, we allow strings for tables in the current schema
                         my $details = ref $parent ? $parent : { name => $parent };
                         $log->tracef('Parent table is %s', $details);
-                        my $target_schema = $schema;
+                        my $target_schema = $self->schema_by_name($details->{schema} // $schema->name);
                         push @parents, (
-                            $schema->table_by_name($details->{name})
-                                or die 'parent table ' . $details->{name} . ' not found'
+                            $target_schema->table_by_name($details->{name})
+                                or die 'parent table ' . $details->{name} . ' not found in schema ' . $target_schema->name
                         );
                     }
                 }
+                if(my $constraints = $item->{details}{constraints}) {
+                    for my $fk (@$constraints) {
+                        next unless $fk->{type} eq 'foreign_key';
+                        die 'FK table ' . $fk->{references}{table} . ' not found' unless $schema->table_by_name($fk->{references}{table});
+                    }
+                }
                 my $table = $self->populate_table(
                     schema  => $schema,
                     details => $table_details,
